==> estateplat-common-1.2.1-20170516.083041-19-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjZdJsydsyb.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/5/3
 * @description 权籍，宗地建设用地使用表视图
 */
@Table(name = "djsj_zd_jsydsyb")
public class DjsjZdJsydsyb {
    @Id
    private String zd_jsydsyb_index;//主键
    private String djh;//地籍号
    private String xmmc;//项目名称
    private String xmzl;//项目地址
    private String kfqymc;//开发企业名称
    private Double tdmj;//土地面积
    private String tdsyqzh;//土地使用权证号
    private Double ghzjzmj;//规划总建筑面积
    private Double dxrfjzmj;//地下人防建筑面积
    private Integer ghlzs;//规划楼幢数
    private Double sczjzmj;//实测总建筑面积
    private Double yrwxszjzmj;//已入网销售总建筑面积
    private Double syjzmj;//剩余建筑面积
    private Double syjsydsyqbl;//剩余建设用地使用权比例
    private String bz;//备注
    private String bgbh;//变更编号

    public String getZd_jsydsyb_index() {
        return zd_jsydsyb_index;
    }

    public void setZd_jsydsyb_index(String zd_jsydsyb_index) {
        this.zd_jsydsyb_index = zd_jsydsyb_index;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXmzl() {
        return xmzl;
    }

    public void setXmzl(String xmzl) {
        this.xmzl = xmzl;
    }

    public String getKfqymc() {
        return kfqymc;
    }

    public void setKfqymc(String kfqymc) {
        this.kfqymc = kfqymc;
    }

    public Double getTdmj() {
        return tdmj;
    }

    public void setTdmj(Double tdmj) {
        this.tdmj = tdmj;
    }

    public String getTdsyqzh() {
        return tdsyqzh;
    }

    public void setTdsyqzh(String tdsyqzh) {
        this.tdsyqzh = tdsyqzh;
    }

    public Double getGhzjzmj() {
        return ghzjzmj;
    }

    public void setGhzjzmj(Double ghzjzmj) {
        this.ghzjzmj = ghzjzmj;
    }

    public Double getDxrfjzmj() {
        return dxrfjzmj;
    }

    public void setDxrfjzmj(Double dxrfjzmj) {
        this.dxrfjzmj = dxrfjzmj;
    }

    public Integer getGhlzs() {
        return ghlzs;
    }

    public void setGhlzs(Integer ghlzs) {
        this.ghlzs = ghlzs;
    }

    public Double getSczjzmj() {
        return sczjzmj;
    }

    public void setSczjzmj(Double sczjzmj) {
        this.sczjzmj = sczjzmj;
    }

    public Double getYrwxszjzmj() {
        return yrwxszjzmj;
    }

    public void setYrwxszjzmj(Double yrwxszjzmj) {
        this.yrwxszjzmj = yrwxszjzmj;
    }

    public Double getSyjzmj() {
        return syjzmj;
    }

    public void setSyjzmj(Double syjzmj) {
        this.syjzmj = syjzmj;
    }

    public Double getSyjsydsyqbl() {
        return syjsydsyqbl;
    }

    public void setSyjsydsyqbl(Double syjsydsyqbl) {
        this.syjsydsyqbl = syjsydsyqbl;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBgbh() {
        return bgbh;
    }

    public void setBgbh(String bgbh) {
        this.bgbh = bgbh;
    }
}

==> estateplat-common-1.2.4-20210406.091243-699-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjZdJsydsyb.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/5/3
 * @description 权籍，宗地建设用地使用表视图
 */
@Table(name = "djsj_zd_jsydsyb")
public class DjsjZdJsydsyb {
    @Id
    private String zdJsydsybIndex;//主键
    private String djh;//地籍号
    private String xmmc;//项目名称
    private String xmzl;//项目地址
    private String kfqymc;//开发企业名称
    private Double tdmj;//土地面积
    private String tdsyqzh;//土地使用权证号
    private Double ghzjzmj;//规划总建筑面积
    private Double dxrfjzmj;//地下人防建筑面积
    private Integer ghlzs;//规划楼幢数
    private Double sczjzmj;//实测总建筑面积
    private Double yrwxszjzmj;//已入网销售总建筑面积
    private Double syjzmj;//剩余建筑面积
    private Double syjsydsyqbl;//剩余建设用地使用权比例
    private String bz;//备注
    private String bgbh;//变更编号

    public String getZdJsydsybIndex() {
        return zdJsydsybIndex;
    }

    public void setZdJsydsybIndex(String zdJsydsybIndex) {
        this.zdJsydsybIndex = zdJsydsybIndex;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXmzl() {
        return xmzl;
    }

    public void setXmzl(String xmzl) {
        this.xmzl = xmzl;
    }

    public String getKfqymc() {
        return kfqymc;
    }

    public void setKfqymc(String kfqymc) {
        this.kfqymc = kfqymc;
    }

    public Double getTdmj() {
        return tdmj;
    }

    public void setTdmj(Double tdmj) {
        this.tdmj = tdmj;
    }

    public String getTdsyqzh() {
        return tdsyqzh;
    }

    public void setTdsyqzh(String tdsyqzh) {
        this.tdsyqzh = tdsyqzh;
    }

    public Double getGhzjzmj() {
        return ghzjzmj;
    }

    public void setGhzjzmj(Double ghzjzmj) {
        this.ghzjzmj = ghzjzmj;
    }

    public Double getDxrfjzmj() {
        return dxrfjzmj;
    }

    public void setDxrfjzmj(Double dxrfjzmj) {
        this.dxrfjzmj = dxrfjzmj;
    }

    public Integer getGhlzs() {
        return ghlzs;
    }

    public void setGhlzs(Integer ghlzs) {
        this.ghlzs = ghlzs;
    }

    public Double getSczjzmj() {
        return sczjzmj;
    }

    public void setSczjzmj(Double sczjzmj) {
        this.sczjzmj = sczjzmj;
    }

    public Double getYrwxszjzmj() {
        return yrwxszjzmj;
    }

    public void setYrwxszjzmj(Double yrwxszjzmj) {
        this.yrwxszjzmj = yrwxszjzmj;
    }

    public Double getSyjzmj() {
        return syjzmj;
    }

    public void setSyjzmj(Double syjzmj) {
        this.syjzmj = syjzmj;
    }

    public Double getSyjsydsyqbl() {
        return syjsydsyqbl;
    }

    public void setSyjsydsyqbl(Double syjsydsyqbl) {
        this.syjsydsyqbl = syjsydsyqbl;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBgbh() {
        return bgbh;
    }

    public void setBgbh(String bgbh) {
        this.bgbh = bgbh;
    }
}
